import React from 'react';
import { Table } from "react-bootstrap";

interface configProps {
    data: Map<string, Map<number, { [key: string]: string }>>;
    dottedBorder?: boolean;
    columns: { [key: string]: string };
}

function getJSXFromData({ data, dottedBorder = false, columns }: configProps) {
    return Array.from(data.entries()).map(([nren, nrenMap]) => {
        return Array.from(nrenMap.entries()).map(([year, yearData], yearIndex) => {
            return (
                <tr key={nren + year} className={dottedBorder ? 'dotted-border' : ''}>
                    <td className='pt-3 nren-column text-nowrap'>{yearIndex === 0 && nren}</td>
                    <td className='pt-3 year-column'>{year}</td>
                    {
                        Object.keys(columns).map((column, index) => {
                            return <td key={index} className='pt-3 blue-column'>{yearData[column]}</td>
                        })
                    }
                </tr>
            )
        });
    });
}

function NrenYearTable({ data, dottedBorder, columns }: configProps) {

    return (<Table borderless className='compendium-table'>
        <thead>
            <tr>
                <th className='nren-column'><span>NREN</span></th>
                <th className='year-column'><span>Year</span></th>
                {Object.values(columns).map((column, index) => <th key={index} className='blue-column'><span>{column}</span></th>)}
            </tr>
        </thead>
        <tbody>
            {getJSXFromData({ data, dottedBorder, columns })}
        </tbody>
    </Table>
    );
}

export default NrenYearTable;
