import React from 'react';
import { Table } from "react-bootstrap";
import { addHttpIfMissing } from 'compendium/helpers/dataconversion';

interface configProps {
    dottedBorder?: boolean;
    noDots?: boolean;
    keysAreURLs?: boolean;
    removeDecoration?: boolean;
}

function getUrlOrString(keysAreURLs, style, index, key, value: string) {
    if (!keysAreURLs) {
        return <li key={index}>
            <span>{value}</span>
        </li>
    }

    const isURL = key.startsWith('http');

    if (!isURL) {
        return <li key={index}>
            <span>{value}</span>
        </li>
    }

    return (<li key={index}>
        <a href={addHttpIfMissing(key)} target="_blank" rel="noopener noreferrer" style={style}>{value}</a>
    </li>)

}

function getJSXFromData(data: Map<string, Map<number, { [key: string]: string }>>,
    { dottedBorder = false, noDots = false, keysAreURLs = false, removeDecoration = false }: configProps) {
    return Array.from(data.entries()).map(([nren, nrenMap]) => {
        return Array.from(nrenMap.entries()).map(([year, yearData], yearIndex) => {
            const style = {} as React.CSSProperties;
            if (removeDecoration) {
                style.textDecoration = 'none';
            }
            return (
                <tr key={nren + year} className={dottedBorder ? 'dotted-border' : ''}>
                    <td className='pt-3 nren-column text-nowrap'>{yearIndex === 0 && nren}</td>
                    <td className='pt-3 year-column'>{year}</td>
                    <td className='pt-3 blue-column'>
                        <ul className={noDots ? 'no-list-style-type' : ''}>
                            {Array.from(Object.entries(yearData)).map(([text, key], index) => {
                                return getUrlOrString(keysAreURLs, style, index, key, text);
                            })}
                        </ul>
                    </td>
                </tr>
            )
        });
    });
}

interface NrenYearTableProps extends configProps {
    data: Map<string, Map<number, { [key: string]: string }>>;
    columnTitle: string;
}

function NrenYearTable({ data, columnTitle, dottedBorder, noDots, keysAreURLs, removeDecoration }: NrenYearTableProps) {

    return (<Table borderless className='compendium-table'>
        <thead>
            <tr>
                <th className='nren-column'><span>NREN</span></th>
                <th className='year-column'><span>Year</span></th>
                <th className='blue-column'><span>{columnTitle}</span></th>
            </tr>
        </thead>
        <tbody>
            {getJSXFromData(data, { dottedBorder, noDots, keysAreURLs, removeDecoration })}
        </tbody>
    </Table>
    );
}

export default NrenYearTable;
