import React, { useEffect, useState } from 'react';
// import { sidebarContext } from "compendium/providers/SidebarProvider";
import { AiOutlineClose, AiOutlinePlus } from 'react-icons/ai';

interface Props {
    children: React.ReactNode;
    survey?: boolean;
}

// check if click outside of sidebar, then toggle it

const Sidebar: React.FC<Props> = ({ children, survey }) => {

    const [show, setShow] = useState<boolean>(false);

    const toggle = (e) => {
        e.stopPropagation();
        e.preventDefault();
        setShow(!show);
    };

    const clickOutside = (e) => {
        // check if the click was inside the sidebar or the menu button
        // if it was outside, close the sidebar
        if (e.target.closest('#sidebar') || e.target.closest('.toggle-btn')) {
            return;
        }
        setShow(false);
    }
    useEffect(() => {
        document.addEventListener('click', clickOutside);
        return () => {
            document.removeEventListener('click', clickOutside);
        }
    });

    const classNames: string[] = [];
    if (!show) {
        classNames.push('no-sidebar')
    }
    if (survey) {
        classNames.push('survey')
    }

    return (
        <div className="sidebar-wrapper">
            <nav className={classNames.join(" ")} id="sidebar">
                <div className={`menu-items`}>{children}</div>
            </nav>
            <div className={`toggle-btn${survey ? "-survey" : ""}`} onClick={toggle}>
                <div className='toggle-btn-wrapper'>
                    <span>MENU</span> {show ?
                        <AiOutlineClose style={{ color: 'white', paddingBottom: "3px", scale: "1.3" }} onClick={toggle} /> :
                        <AiOutlinePlus style={{ color: 'white', paddingBottom: "3px", scale: "1.3" }} onClick={toggle} />}
                </div>
            </div>
        </div>
    );
};

export default Sidebar;