import { useCallback, useContext } from 'react'
import { MatomoContext } from 'compendium/matomo/MatomoProvider'
import {
    TrackEventParams,
    TrackLinkParams,
    TrackPageViewParams
} from 'compendium/matomo/types'

function useMatomo() {
    const instance = useContext(MatomoContext)

    const trackPageView = useCallback(
        (params?: TrackPageViewParams) => instance?.trackPageView(params),
        [instance],
    )

    const trackEvent = useCallback(
        (params: TrackEventParams) => instance?.trackEvent(params),
        [instance],
    )

    const trackEvents = useCallback(() => instance?.trackEvents(), [instance])

    const trackLink = useCallback(
        (params: TrackLinkParams) => instance?.trackLink(params),
        [instance],
    )

    const enableLinkTracking = useCallback(() => {
        // no link tracking for now
    }, [])

    const pushInstruction = useCallback(
        (name: string, ...args: any[]) => { // eslint-disable-line @typescript-eslint/no-explicit-any

            instance?.pushInstruction(name, ...args)
        },
        [instance],
    )

    return {
        trackEvent,
        trackEvents,
        trackPageView,
        trackLink,
        enableLinkTracking,
        pushInstruction,
    }
}

export default useMatomo