import React, { useContext } from "react";
import { CertificateProviders } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function CertificateProviderPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<CertificateProviders>('/api/certificate-providers', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'provider_names');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const columns = [
        "TCS",
        "Digicert",
        "Sectigo (outside of TCS)",
        "Let's Encrypt",
        "Entrust Datacard",
    ]

    // The Sectigo column is different from the data value, so we need to map it here
    const columnValueMap = new Map<string, string>([
        ["Sectigo (outside of TCS)", "Sectigo"],
    ]);

    return (
        <DataPage title={titles["certificate-provider"]}
            description="The table below shows the kinds of Network Certificate Providers used by NRENs."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="certificate_provider_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} dataLookup={dataLookup} circle columnLookup={columnValueMap} />
            </ChartContainer>
        </DataPage>
    );
}
export default CertificateProviderPage;
