import React, { useContext } from "react";
import { OPsAutomation } from "compendium/Schema";
import { createNrenTableLookup, addTooltip } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function OPsAutomationPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<OPsAutomation>('/api/ops-automation', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'ops_automation');

    const processTooltip = (column: string, ops: OPsAutomation) => {
        if (!ops.ops_automation_specifics) {
            return;
        }
        return ops.ops_automation_specifics;
    }

    const withTooltip = addTooltip(dataLookup, processTooltip);

    const columns = [
        "Yes",
        "Planned",
        "No",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "yes"],
        [columns[1], "planned"],
        [columns[2], "no"],
    ]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles["ops-automation"]}
            description="The table below shows which NRENs have, or plan to, automate their 
            operational processes, with specification of which processes, and the names of 
            software and tools used for this given when appropriate."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="ops_automation_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} columnLookup={columnValueMap} dataLookup={withTooltip} />
            </ChartContainer>
        </DataPage>
    );
}
export default OPsAutomationPage;
