import React, { useContext } from "react";
import { PertTeam } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function PertTeamPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<PertTeam>('/api/pert-team', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'pert_team');

    const columns = [
        "Yes",
        "Planned",
        "No",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "yes"],
        [columns[1], "planned"],
        [columns[2], "no"],
    ]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles['pert-team']}
            description="Some NRENs have an in-house Performance Enhancement Response Team, 
            or PERT, to investigate network performance issues."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="pert_team_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} columnLookup={columnValueMap} dataLookup={dataLookup} />
            </ChartContainer>
        </DataPage>
    );
}
export default PertTeamPage;
