import { useContext } from 'react';

import { ECProject } from "compendium/Schema";
import { createDataLookupList, getTableData } from 'compendium/helpers/dataconversion';
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from 'compendium/helpers/useData';
import NrenYearTable from 'compendium/components/NrenYearTable';

function ECProjectsPage() {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data: projectData, years, nrens } = useData<ECProject>('/api/ec-project', setFilterSelection);

    const selectedData = (projectData).filter(project =>
        filterSelection.selectedYears.includes(project.year) && filterSelection.selectedNrens.includes(project.nren)
    );
    const projectDataByYear = createDataLookupList(selectedData);

    const addValueToObject = (obj: { [key: string]: string }, data: ECProject[]) => {
        const projects = data.map(project => project.project).sort();
        if (!projects.length) return;
        projects.forEach((value) => {
            obj[value] = value;
        });
    }

    const dataByYear = getTableData(projectDataByYear, addValueToObject);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title="NREN Involvement in European Commission Projects"
            description='Many NRENs are involved in a number of different European Commission project, besides GÉANT. The list of projects in the table below is not necessarily exhaustive, but does contain projects the NRENs consider important or worthy of mention.'
            category={Sections.Organisation} filter={filterNode}
            data={selectedData} filename='nren_involvement_in_european_commission_projects'>
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="EC Project Membership" dottedBorder />
            </ChartContainer>
        </DataPage>
    )
}
export default ECProjectsPage;
