import { useContext } from 'react';

import { Policy } from "compendium/Schema";
import { createDataLookup, getLatestData, getTableData } from 'compendium/helpers/dataconversion';
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import { useData } from 'compendium/helpers/useData';
import ChartContainer from 'compendium/components/graphing/ChartContainer';
import NrenYearTable from 'compendium/components/NrenYearTable';
import titles from "compendium/titles";

function PolicyPage() {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data: fetchedData, nrens } = useData<Policy>('/api/policy', setFilterSelection);

    const policyData = fetchedData ? getLatestData(fetchedData) : [];

    const selectedData = policyData.filter(project =>
        filterSelection.selectedNrens.includes(project.nren)
    );
    const policyDataByYear = createDataLookup(selectedData);

    const dataByYear = getTableData(policyDataByYear, (obj, policy) => {
        const policies = [
            ['acceptable_use', 'Acceptable Use Policy'],
            ['connectivity', 'Connectivity Policy'],
            ['data_protection', 'Data Protection Policy'],
            ['environmental', 'Environmental Policy'],
            ['equal_opportunity', 'Equal Opportunity Policy'],
            ['gender_equality', 'Gender Equality Plan'],
            ['privacy_notice', 'Privacy Notice'],
        ];
        policies.forEach(([key, text]) => {
            const value = policy[key];
            if (value) {
                obj[text] = value;
            }
        })
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title={titles.policy}
            description='The table shows links to the NRENs policies. We only include links from the most recent response from each NREN.'
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename='nren_policies'>
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Policies" noDots dottedBorder keysAreURLs removeDecoration />
            </ChartContainer>
        </DataPage>
    )
}
export default PolicyPage;
