import React, { useContext } from "react";
import { SecurityControls } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function SecurityControlsPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<SecurityControls>('/api/security-controls', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'security_control_descriptions');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const stringMap = {
        "anti_virus": "Anti Virus",
        "anti_spam": "Anti-Spam",
        "firewall": "Firewall",
        "ddos_mitigation": "DDoS mitigation",
        "monitoring": "Network monitoring",
        "ips_ids": "IPS/IDS",
        "acl": "ACL",
        "segmentation": "Network segmentation",
        "integrity_checking": "Integrity checking"
    }

    const columnValueMap = new Map<string, string>(
        Object.entries(stringMap).map(([key, value]) => [value, key])
    );

    return (
        <DataPage title={titles["security-control"]}
            description="The table below shows the different security controls, such as anti-virus, integrity checkers, and systemic firewalls used by 
            NRENs to protect their assets. Where 'other' controls are mentioned, hover over the marker for more information."
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename="security_control_nrens_per_year">
            <ChartContainer>
                <PillTable columns={Object.values(stringMap)} dataLookup={dataLookup} circle columnLookup={columnValueMap} />
            </ChartContainer>
        </DataPage>
    );
}
export default SecurityControlsPage;
