import React, { Dispatch, SetStateAction, createContext, useState, useEffect } from 'react';
import { Nren } from "compendium/Schema";

interface Props {
    children: React.ReactNode;
}

async function fetchNrens(): Promise<Nren[]> {
    try {
        const response = await fetch('/api/nren/list');
        const userList = await response.json();
        return userList
    } catch {
        return [];
    }
}

const NrenContext = createContext<{
    nrens: Nren[];
    setNrens: Dispatch<SetStateAction<Nren[]>>;
}>({
    nrens: [],
    setNrens: () => { }
});

const NrenProvider: React.FC<Props> = ({ children }) => {
    const [nrens, setNrens] = useState<Nren[]>([]);

    useEffect(() => {
        fetchNrens().then((nrens) => setNrens(nrens));
    }, []);

    return (
        <NrenContext.Provider value={{ nrens, setNrens }}>
            {children}
        </NrenContext.Provider>
    );
};

export { NrenContext };
export default NrenProvider;