import { validateQuestion, oldValidateWebsiteUrl } from 'compendium/survey/validation/validation';

export async function validateSurvey(year, nren) {
    const { Model, FunctionFactory, Serializer } = await import('survey-core');

    function setupProperties() {
        const descriptionProperty = Serializer.getAllPropertiesByName("customDescription");
        const hideCheckboxLabelsProperty = Serializer.getAllPropertiesByName("hideCheckboxLabels");

        if (!descriptionProperty.length) {
            Serializer.addProperty("itemvalue", "customDescription:text");
        }
        if (!hideCheckboxLabelsProperty.length) {
            Serializer.addProperty("question", "hideCheckboxLabels:boolean");
        }
    }

    if (!FunctionFactory.Instance.hasFunction("validateQuestion")) {
        FunctionFactory.Instance.register("validateQuestion", validateQuestion);
    }

    if (!FunctionFactory.Instance.hasFunction("validateWebsiteUrl")) {
        FunctionFactory.Instance.register("validateWebsiteUrl", oldValidateWebsiteUrl);
    }

    if (!year || !nren) {
        return true;
    }
    const url = `/api/response/load/${year}/${nren}`;

    const response = await fetch(url);
    const json = await response.json();

    if (!response.ok) {

        if ('message' in json) {
            throw new Error(json.message);
        } else {
            throw new Error(`Request failed with status ${response.status}`);
        }
    }

    // Setup custom properties that allow the survey to work
    setupProperties();

    const survey = new Model(json['model']);
    survey.setVariable('surveyyear', year);
    survey.setVariable('previousyear', parseInt(year!) - 1);

    survey.showNavigationButtons = false;
    survey.requiredText = '';

    survey.data = json['data'];
    survey.clearIncorrectValues(true);

    const valid = survey.validate.bind(survey, true, true)();

    const validResponse = await fetch(`/api/response/validate/${year}/${nren}`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ 'valid': valid }),
    });

    if (!validResponse.ok) {
        // we might attempt validation for surveys that don't exist yet, so just ignore the error
        return true;
    }

    return valid;
}