import { defineConfig } from 'vite'
import react from '@vitejs/plugin-react'
import license from 'rollup-plugin-license'
import path from 'path'

const ReactCompilerConfig = {
    target: "19"
};
const outDir = path.resolve(__dirname, '..', 'compendium_v2', 'static');

const isProduction = process.env.NODE_ENV === 'production';
console.log(isProduction ? 'Production build' : 'Development build');

export default defineConfig({
    // assetsInclude: ['**/*.png', '**/*.jpg', '**/*.svg'],
    plugins: [react(
        {
            babel: {
                plugins: [
                    ["babel-plugin-react-compiler", ReactCompilerConfig],
                ]
            }
        }), license({
            thirdParty: {
                output: path.join(outDir, 'third-party-licenses.txt'),
            }
        })],
    base: isProduction ? '/static/' : '/',
    server: {
        port: 4000,
        host: '::',
        proxy: {
            '/api': {
                target: 'http://127.0.0.1:5000',
                autoRewrite: true,
            },
            '/login': {
                target: 'http://127.0.0.1:5000',
                autoRewrite: true,
            },
            '/logout': {
                target: 'http://127.0.0.1:5000',
                autoRewrite: true,

            },
            '/authorize': {
                target: 'http://127.0.0.1:5000',
                autoRewrite: true,
            },
        }
    },
    build: {
        assetsInlineLimit: 0, // remove limit for inlining assets like images, we don't want to inline anything
        outDir: outDir,
        sourcemap: process.env.NODE_ENV !== 'production',
        rollupOptions: {
            output: {
                entryFileNames: '[name].js',
                assetFileNames: function (assetInfo) {
                    const names = assetInfo.names;
                    if (names.some(name => name.endsWith('.css'))) {
                        if (names.some(name => name.toLowerCase().includes('component'))) {
                            return '[hash].[ext]';
                        }
                        return '[name].[ext]';
                    }
                    return '[hash].[ext]';

                },
                manualChunks: undefined,
                chunkFileNames: '[name]-[hash].js',
            },
        },
    },
    resolve: {
        alias: {
            'compendium': path.resolve(__dirname, 'src'),
        }
    },
})